@@ -4,17 +4,20 @@ prodlimIcensSurv <- function(response,
                              maxiter,
                              ml=FALSE,
                              exact=TRUE){
+
+  # {{{ data
   ntol <- 10^{-tol}
   L <- response[,"L"]
   N <- length(L)
   R <- response[,"R"]
   status <- response[,"status"]
-  if (ml==FALSE) {
+  # }}}
+  # {{{ one-step idea
 
+  if (ml==FALSE) {
     # right censored observations
     # are defined by status
     R[status==0] <- L[status==0]
-    
     if (missing(grid))
       grid <- sort(unique(c(L,R)))
     else
@@ -40,8 +43,51 @@ prodlimIcensSurv <- function(response,
     indexL <- match(L,grid)
     NS <- length(grid)
     Ind <- iindex(L,R,grid)
-    fit <- .C("icens_prodlim",as.double(L),as.double(R),as.double(grid),as.integer(indexL),as.integer(indexR),as.integer(Ind$iindex),as.integer(c(Ind$imax,0)),as.integer(status),as.double(N),as.double(NS),nrisk=double(NS),nevent=double(NS),ncens=double(NS),hazard=double(NS),varhazard=double(NS),surv=double(NS),oldsurv=double(NS),as.double(ntol),as.integer(maxiter),n.iter=integer(1),package="prodim")
-
+    fit <- list("icens_prodlim",
+              as.double(L),
+              as.double(R),
+              as.double(grid),
+              as.integer(indexL),
+              as.integer(indexR),
+              as.integer(Ind$iindex),
+              as.integer(c(Ind$imax,0)),
+              as.integer(status),
+              as.double(N),
+              as.double(NS),
+              nrisk=double(NS),
+              nevent=double(NS),
+              ncens=double(NS),
+              hazard=double(NS),
+              varhazard=double(NS),
+              surv=double(NS),
+              oldsurv=double(NS),
+              as.double(ntol),
+              as.integer(maxiter),
+              n.iter=integer(1),
+              package="prodim")
+##     browser()
+    fit <- .C("icens_prodlim",
+              as.double(L),
+              as.double(R),
+              as.double(grid),
+              as.integer(indexL),
+              as.integer(indexR),
+              as.integer(Ind$iindex),
+              as.integer(c(Ind$imax,0)),
+              as.integer(status),
+              as.double(N),
+              as.double(NS),
+              nrisk=double(NS),
+              nevent=double(NS),
+              ncens=double(NS),
+              hazard=double(NS),
+              varhazard=double(NS),
+              surv=double(NS),
+              oldsurv=double(NS),
+              as.double(ntol),
+              as.integer(maxiter),
+              n.iter=integer(1),
+              package="prodim")
     ## rename the extra grid point before the smallest `L'
     ## if it is negative
     if (grid[1]<0) grid[1] <- 0
@@ -58,6 +104,10 @@ prodlimIcensSurv <- function(response,
     #    res <- list("time"=rbind(c(0,0,grid[-length(grid)]),c(0,grid)),"n.risk"=c(N,round(pmax(0,fit$nrisk),tol)),"n.event"=c(0,round(pmax(0,fit$nevent),tol)),"n.lost"=c(0,round(fit$ncens,tol)),"hazard"=c(0,round(fit$hazard,tol)),"surv"=c(1,round(pmax(0,fit$surv),tol)),"maxtime"=max(grid),"n.iter"=fit$n.iter,"tol"=ntol,"model"="survival")
   }
   else{
+# }}}
+  # {{{ npmle 
+
+    
     ## artificial closure of right censored intervals 
     ## R[Rna] <- max(c(L,R)) + 1
     R[status==0] <- max(c(L,R[status!=0])) + 1
@@ -79,6 +129,8 @@ prodlimIcensSurv <- function(response,
     hazard <- c(0,fit$Z)/surv
     res <- list("time"=cbind(c(0,0),peto.intervals),"n.risk"=N-n.event,"n.event"=n.event,"n.lost"= c(0,rep(0,M)),"hazard"=round(hazard,tol),"surv"=round(surv,tol),"maxtime"=max(c(peto.intervals)),"n.iter"=fit$steps,"tol"=ntol,"model"="survival")
   }
+  # }}}
+
   class(res) <- "prodlim"
   res  
 }
