@@ -8,7 +8,7 @@ library(survival)
 d <- data.frame(time=c(1,2,2,3,4,8,8,8,9),status=c(0,1,0,1,0,1,0,1,1))
 f <- prodlim(Hist(time,status)~1,data=d)
 s <- summary(survfit(Surv(time,status)~1,data=d))
-y <- cbind(s$time,s$n.risk,s$n.event,s$n.censor,s$surv,s$std.err,s$lower,s$lower)
+y <- cbind(s$time,s$n.risk,s$n.event,s$n.censor,s$surv,s$std.err,s$lower,s$upper)
 x <- summary(f,times=s$time)
 all.equal(y,x$table)
 
